@@ -10,37 +10,49 @@ use Regex::Object::Match;
 use Moo;
 use namespace::clean;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
-tie my %nc, "Tie::Hash::NamedCapture";
+tie my %nc,  "Tie::Hash::NamedCapture";
 tie my %nca, "Tie::Hash::NamedCapture", all => 1;
 
 has regex => (
-    is       => 'ro',
+    is => 'ro',
 );
 
 sub match {
     my ($self, $string) = @_;
 
     $string =~ $self->regex;
-
     return $self->collect;
 }
 
 sub collect {
-    my @captures = map {no strict 'refs'; $$_} 1 .. $#-;
-
     return Regex::Object::Match->new(
         prematch           => $PREMATCH,
         match              => $MATCH,
         postmatch          => $POSTMATCH,
         last_paren_match   => $LAST_PAREN_MATCH,
-        captures           => \@captures,
+        captures           => _collect_captures(),
         named_captures     => { %nc },
         named_captures_all => { %nca },
     );
 }
 
+sub _collect_captures {
+    my @captures;
+
+    # Trick to get @captures the most appropriate to language version way.
+    eval {
+        @captures = @{^CAPTURE}; # This was added in 5.25.7.
+    }
+    or do {
+        no strict 'refs';
+        @captures = map { "$$_" } 1 .. $#-;
+    };
+
+    return \@captures;
+}
+
 1;
 
 __END__
@@ -57,7 +69,7 @@ Regex::Object - solves problems with global Regex variables side effects.
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
@@ -110,9 +122,13 @@ The Regex::Object supports two approaches:
 
 =over 4
 
-=item qr// regex passed to constructor, so these modifiers could be used: m,s,i,x,xx,p,a,d,l,u,n.
+=item object scoped regex
 
-=item collecting regex result vars from global match expression, (nothing passed to constructor).
+qr// regex passed to constructor, so these modifiers could be used: m,s,i,x,xx,p,a,d,l,u,n.
+
+=item global regex
+
+collecting regex result vars from global match expression, (nothing passed to constructor).
 
 =back
 
@@ -125,7 +141,7 @@ More about Perl Regex: L<perlre|https://perldoc.perl.org/perlre>.
     my $re = Regex::Object->new(regex  => qr/^\w{3}$/); # scoped qr regex
     my $re = Regex::Object->new; # to work with global match expression
 
-Constructor: accept one parameter - qr// regex and returns new instance.
+Constructor: accept one optional parameter - qr// regex and returns new instance.
 
 =head3 regex()
 
